# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: membership.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from etcetra.grpc_api import gogo_pb2 as gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10membership.proto\x12\x0cmembershippb\x1a\ngogo.proto\"7\n\x0eRaftAttributes\x12\x11\n\tpeer_urls\x18\x01 \x03(\t\x12\x12\n\nis_learner\x18\x02 \x01(\x08\"/\n\nAttributes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x63lient_urls\x18\x02 \x03(\t\"\x80\x01\n\x06Member\x12\n\n\x02ID\x18\x01 \x01(\x04\x12\x35\n\x0fraft_attributes\x18\x02 \x01(\x0b\x32\x1c.membershippb.RaftAttributes\x12\x33\n\x11member_attributes\x18\x03 \x01(\x0b\x32\x18.membershippb.Attributes\"\'\n\x18\x43lusterVersionSetRequest\x12\x0b\n\x03ver\x18\x01 \x01(\t\"e\n\x1b\x43lusterMemberAttrSetRequest\x12\x11\n\tmember_ID\x18\x01 \x01(\x04\x12\x33\n\x11member_attributes\x18\x02 \x01(\x0b\x32\x18.membershippb.Attributes\"7\n\x17\x44owngradeInfoSetRequest\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0b\n\x03ver\x18\x02 \x01(\tB\x10\xc8\xe2\x1e\x01\xe0\xe2\x1e\x01\xd0\xe2\x1e\x01\xc8\xe1\x1e\x00\x62\x06proto3')



_RAFTATTRIBUTES = DESCRIPTOR.message_types_by_name['RaftAttributes']
_ATTRIBUTES = DESCRIPTOR.message_types_by_name['Attributes']
_MEMBER = DESCRIPTOR.message_types_by_name['Member']
_CLUSTERVERSIONSETREQUEST = DESCRIPTOR.message_types_by_name['ClusterVersionSetRequest']
_CLUSTERMEMBERATTRSETREQUEST = DESCRIPTOR.message_types_by_name['ClusterMemberAttrSetRequest']
_DOWNGRADEINFOSETREQUEST = DESCRIPTOR.message_types_by_name['DowngradeInfoSetRequest']
RaftAttributes = _reflection.GeneratedProtocolMessageType('RaftAttributes', (_message.Message,), {
  'DESCRIPTOR' : _RAFTATTRIBUTES,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.RaftAttributes)
  })
_sym_db.RegisterMessage(RaftAttributes)

Attributes = _reflection.GeneratedProtocolMessageType('Attributes', (_message.Message,), {
  'DESCRIPTOR' : _ATTRIBUTES,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.Attributes)
  })
_sym_db.RegisterMessage(Attributes)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), {
  'DESCRIPTOR' : _MEMBER,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.Member)
  })
_sym_db.RegisterMessage(Member)

ClusterVersionSetRequest = _reflection.GeneratedProtocolMessageType('ClusterVersionSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERVERSIONSETREQUEST,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.ClusterVersionSetRequest)
  })
_sym_db.RegisterMessage(ClusterVersionSetRequest)

ClusterMemberAttrSetRequest = _reflection.GeneratedProtocolMessageType('ClusterMemberAttrSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERMEMBERATTRSETREQUEST,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.ClusterMemberAttrSetRequest)
  })
_sym_db.RegisterMessage(ClusterMemberAttrSetRequest)

DowngradeInfoSetRequest = _reflection.GeneratedProtocolMessageType('DowngradeInfoSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNGRADEINFOSETREQUEST,
  '__module__' : 'membership_pb2'
  # @@protoc_insertion_point(class_scope:membershippb.DowngradeInfoSetRequest)
  })
_sym_db.RegisterMessage(DowngradeInfoSetRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\310\342\036\001\340\342\036\001\320\342\036\001\310\341\036\000'
  _RAFTATTRIBUTES._serialized_start=46
  _RAFTATTRIBUTES._serialized_end=101
  _ATTRIBUTES._serialized_start=103
  _ATTRIBUTES._serialized_end=150
  _MEMBER._serialized_start=153
  _MEMBER._serialized_end=281
  _CLUSTERVERSIONSETREQUEST._serialized_start=283
  _CLUSTERVERSIONSETREQUEST._serialized_end=322
  _CLUSTERMEMBERATTRSETREQUEST._serialized_start=324
  _CLUSTERMEMBERATTRSETREQUEST._serialized_end=425
  _DOWNGRADEINFOSETREQUEST._serialized_start=427
  _DOWNGRADEINFOSETREQUEST._serialized_end=482
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from etcetra.grpc_api import gogo_pb2 as gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x06\x61uthpb\x1a\ngogo.proto\"%\n\x0eUserAddOptions\x12\x13\n\x0bno_password\x18\x01 \x01(\x08\"^\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\x0c\x12\x10\n\x08password\x18\x02 \x01(\x0c\x12\r\n\x05roles\x18\x03 \x03(\t\x12\'\n\x07options\x18\x04 \x01(\x0b\x32\x16.authpb.UserAddOptions\"\x83\x01\n\nPermission\x12)\n\x08permType\x18\x01 \x01(\x0e\x32\x17.authpb.Permission.Type\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x11\n\trange_end\x18\x03 \x01(\x0c\"*\n\x04Type\x12\x08\n\x04READ\x10\x00\x12\t\n\x05WRITE\x10\x01\x12\r\n\tREADWRITE\x10\x02\"?\n\x04Role\x12\x0c\n\x04name\x18\x01 \x01(\x0c\x12)\n\rkeyPermission\x18\x02 \x03(\x0b\x32\x12.authpb.PermissionB\x14\xc8\xe2\x1e\x01\xe0\xe2\x1e\x01\xd0\xe2\x1e\x01\xc8\xe1\x1e\x00\xd0\xe1\x1e\x00\x62\x06proto3')



_USERADDOPTIONS = DESCRIPTOR.message_types_by_name['UserAddOptions']
_USER = DESCRIPTOR.message_types_by_name['User']
_PERMISSION = DESCRIPTOR.message_types_by_name['Permission']
_ROLE = DESCRIPTOR.message_types_by_name['Role']
_PERMISSION_TYPE = _PERMISSION.enum_types_by_name['Type']
UserAddOptions = _reflection.GeneratedProtocolMessageType('UserAddOptions', (_message.Message,), {
  'DESCRIPTOR' : _USERADDOPTIONS,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:authpb.UserAddOptions)
  })
_sym_db.RegisterMessage(UserAddOptions)

User = _reflection.GeneratedProtocolMessageType('User', (_message.Message,), {
  'DESCRIPTOR' : _USER,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:authpb.User)
  })
_sym_db.RegisterMessage(User)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:authpb.Permission)
  })
_sym_db.RegisterMessage(Permission)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'auth_pb2'
  # @@protoc_insertion_point(class_scope:authpb.Role)
  })
_sym_db.RegisterMessage(Role)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\310\342\036\001\340\342\036\001\320\342\036\001\310\341\036\000\320\341\036\000'
  _USERADDOPTIONS._serialized_start=34
  _USERADDOPTIONS._serialized_end=71
  _USER._serialized_start=73
  _USER._serialized_end=167
  _PERMISSION._serialized_start=170
  _PERMISSION._serialized_end=301
  _PERMISSION_TYPE._serialized_start=259
  _PERMISSION_TYPE._serialized_end=301
  _ROLE._serialized_start=303
  _ROLE._serialized_end=366
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from etcetra.grpc_api import gogo_pb2 as gogo__pb2
from etcetra.grpc_api import kv_pb2 as kv__pb2
from etcetra.grpc_api import auth_pb2 as auth__pb2
from etcetra.grpc_api import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\trpc.proto\x12\x0c\x65tcdserverpb\x1a\ngogo.proto\x1a\x08kv.proto\x1a\nauth.proto\x1a\x11\x61nnotations.proto\"\\\n\x0eResponseHeader\x12\x12\n\ncluster_id\x18\x01 \x01(\x04\x12\x11\n\tmember_id\x18\x02 \x01(\x04\x12\x10\n\x08revision\x18\x03 \x01(\x03\x12\x11\n\traft_term\x18\x04 \x01(\x04\"\xe4\x03\n\x0cRangeRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x11\n\trange_end\x18\x02 \x01(\x0c\x12\r\n\x05limit\x18\x03 \x01(\x03\x12\x10\n\x08revision\x18\x04 \x01(\x03\x12\x38\n\nsort_order\x18\x05 \x01(\x0e\x32$.etcdserverpb.RangeRequest.SortOrder\x12:\n\x0bsort_target\x18\x06 \x01(\x0e\x32%.etcdserverpb.RangeRequest.SortTarget\x12\x14\n\x0cserializable\x18\x07 \x01(\x08\x12\x11\n\tkeys_only\x18\x08 \x01(\x08\x12\x12\n\ncount_only\x18\t \x01(\x08\x12\x18\n\x10min_mod_revision\x18\n \x01(\x03\x12\x18\n\x10max_mod_revision\x18\x0b \x01(\x03\x12\x1b\n\x13min_create_revision\x18\x0c \x01(\x03\x12\x1b\n\x13max_create_revision\x18\r \x01(\x03\".\n\tSortOrder\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x41SCEND\x10\x01\x12\x0b\n\x07\x44\x45SCEND\x10\x02\"B\n\nSortTarget\x12\x07\n\x03KEY\x10\x00\x12\x0b\n\x07VERSION\x10\x01\x12\n\n\x06\x43REATE\x10\x02\x12\x07\n\x03MOD\x10\x03\x12\t\n\x05VALUE\x10\x04\"y\n\rRangeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x1d\n\x03kvs\x18\x02 \x03(\x0b\x32\x10.mvccpb.KeyValue\x12\x0c\n\x04more\x18\x03 \x01(\x08\x12\r\n\x05\x63ount\x18\x04 \x01(\x03\"t\n\nPutRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\r\n\x05lease\x18\x03 \x01(\x03\x12\x0f\n\x07prev_kv\x18\x04 \x01(\x08\x12\x14\n\x0cignore_value\x18\x05 \x01(\x08\x12\x14\n\x0cignore_lease\x18\x06 \x01(\x08\"^\n\x0bPutResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12!\n\x07prev_kv\x18\x02 \x01(\x0b\x32\x10.mvccpb.KeyValue\"E\n\x12\x44\x65leteRangeRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x11\n\trange_end\x18\x02 \x01(\x0c\x12\x0f\n\x07prev_kv\x18\x03 \x01(\x08\"x\n\x13\x44\x65leteRangeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x0f\n\x07\x64\x65leted\x18\x02 \x01(\x03\x12\"\n\x08prev_kvs\x18\x03 \x03(\x0b\x32\x10.mvccpb.KeyValue\"\xef\x01\n\tRequestOp\x12\x33\n\rrequest_range\x18\x01 \x01(\x0b\x32\x1a.etcdserverpb.RangeRequestH\x00\x12/\n\x0brequest_put\x18\x02 \x01(\x0b\x32\x18.etcdserverpb.PutRequestH\x00\x12@\n\x14request_delete_range\x18\x03 \x01(\x0b\x32 .etcdserverpb.DeleteRangeRequestH\x00\x12/\n\x0brequest_txn\x18\x04 \x01(\x0b\x32\x18.etcdserverpb.TxnRequestH\x00\x42\t\n\x07request\"\xf9\x01\n\nResponseOp\x12\x35\n\x0eresponse_range\x18\x01 \x01(\x0b\x32\x1b.etcdserverpb.RangeResponseH\x00\x12\x31\n\x0cresponse_put\x18\x02 \x01(\x0b\x32\x19.etcdserverpb.PutResponseH\x00\x12\x42\n\x15response_delete_range\x18\x03 \x01(\x0b\x32!.etcdserverpb.DeleteRangeResponseH\x00\x12\x31\n\x0cresponse_txn\x18\x04 \x01(\x0b\x32\x19.etcdserverpb.TxnResponseH\x00\x42\n\n\x08response\"\x96\x03\n\x07\x43ompare\x12\x33\n\x06result\x18\x01 \x01(\x0e\x32#.etcdserverpb.Compare.CompareResult\x12\x33\n\x06target\x18\x02 \x01(\x0e\x32#.etcdserverpb.Compare.CompareTarget\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x12\x11\n\x07version\x18\x04 \x01(\x03H\x00\x12\x19\n\x0f\x63reate_revision\x18\x05 \x01(\x03H\x00\x12\x16\n\x0cmod_revision\x18\x06 \x01(\x03H\x00\x12\x0f\n\x05value\x18\x07 \x01(\x0cH\x00\x12\x0f\n\x05lease\x18\x08 \x01(\x03H\x00\x12\x11\n\trange_end\x18@ \x01(\x0c\"@\n\rCompareResult\x12\t\n\x05\x45QUAL\x10\x00\x12\x0b\n\x07GREATER\x10\x01\x12\x08\n\x04LESS\x10\x02\x12\r\n\tNOT_EQUAL\x10\x03\"G\n\rCompareTarget\x12\x0b\n\x07VERSION\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x07\n\x03MOD\x10\x02\x12\t\n\x05VALUE\x10\x03\x12\t\n\x05LEASE\x10\x04\x42\x0e\n\x0ctarget_union\"\x88\x01\n\nTxnRequest\x12&\n\x07\x63ompare\x18\x01 \x03(\x0b\x32\x15.etcdserverpb.Compare\x12(\n\x07success\x18\x02 \x03(\x0b\x32\x17.etcdserverpb.RequestOp\x12(\n\x07\x66\x61ilure\x18\x03 \x03(\x0b\x32\x17.etcdserverpb.RequestOp\"{\n\x0bTxnResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x11\n\tsucceeded\x18\x02 \x01(\x08\x12+\n\tresponses\x18\x03 \x03(\x0b\x32\x18.etcdserverpb.ResponseOp\"7\n\x11\x43ompactionRequest\x12\x10\n\x08revision\x18\x01 \x01(\x03\x12\x10\n\x08physical\x18\x02 \x01(\x08\"B\n\x12\x43ompactionResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"\r\n\x0bHashRequest\"!\n\rHashKVRequest\x12\x10\n\x08revision\x18\x01 \x01(\x03\"f\n\x0eHashKVResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x0c\n\x04hash\x18\x02 \x01(\r\x12\x18\n\x10\x63ompact_revision\x18\x03 \x01(\x03\"J\n\x0cHashResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x0c\n\x04hash\x18\x02 \x01(\r\"\x11\n\x0fSnapshotRequest\"g\n\x10SnapshotResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x17\n\x0fremaining_bytes\x18\x02 \x01(\x04\x12\x0c\n\x04\x62lob\x18\x03 \x01(\x0c\"\xd7\x01\n\x0cWatchRequest\x12:\n\x0e\x63reate_request\x18\x01 \x01(\x0b\x32 .etcdserverpb.WatchCreateRequestH\x00\x12:\n\x0e\x63\x61ncel_request\x18\x02 \x01(\x0b\x32 .etcdserverpb.WatchCancelRequestH\x00\x12>\n\x10progress_request\x18\x03 \x01(\x0b\x32\".etcdserverpb.WatchProgressRequestH\x00\x42\x0f\n\rrequest_union\"\xff\x01\n\x12WatchCreateRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x11\n\trange_end\x18\x02 \x01(\x0c\x12\x16\n\x0estart_revision\x18\x03 \x01(\x03\x12\x17\n\x0fprogress_notify\x18\x04 \x01(\x08\x12<\n\x07\x66ilters\x18\x05 \x03(\x0e\x32+.etcdserverpb.WatchCreateRequest.FilterType\x12\x0f\n\x07prev_kv\x18\x06 \x01(\x08\x12\x10\n\x08watch_id\x18\x07 \x01(\x03\x12\x10\n\x08\x66ragment\x18\x08 \x01(\x08\"%\n\nFilterType\x12\t\n\x05NOPUT\x10\x00\x12\x0c\n\x08NODELETE\x10\x01\"&\n\x12WatchCancelRequest\x12\x10\n\x08watch_id\x18\x01 \x01(\x03\"\x16\n\x14WatchProgressRequest\"\xd4\x01\n\rWatchResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x10\n\x08watch_id\x18\x02 \x01(\x03\x12\x0f\n\x07\x63reated\x18\x03 \x01(\x08\x12\x10\n\x08\x63\x61nceled\x18\x04 \x01(\x08\x12\x18\n\x10\x63ompact_revision\x18\x05 \x01(\x03\x12\x15\n\rcancel_reason\x18\x06 \x01(\t\x12\x10\n\x08\x66ragment\x18\x07 \x01(\x08\x12\x1d\n\x06\x65vents\x18\x0b \x03(\x0b\x32\r.mvccpb.Event\",\n\x11LeaseGrantRequest\x12\x0b\n\x03TTL\x18\x01 \x01(\x03\x12\n\n\x02ID\x18\x02 \x01(\x03\"j\n\x12LeaseGrantResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\n\n\x02ID\x18\x02 \x01(\x03\x12\x0b\n\x03TTL\x18\x03 \x01(\x03\x12\r\n\x05\x65rror\x18\x04 \x01(\t\" \n\x12LeaseRevokeRequest\x12\n\n\x02ID\x18\x01 \x01(\x03\"C\n\x13LeaseRevokeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"4\n\x0fLeaseCheckpoint\x12\n\n\x02ID\x18\x01 \x01(\x03\x12\x15\n\rremaining_TTL\x18\x02 \x01(\x03\"L\n\x16LeaseCheckpointRequest\x12\x32\n\x0b\x63heckpoints\x18\x01 \x03(\x0b\x32\x1d.etcdserverpb.LeaseCheckpoint\"G\n\x17LeaseCheckpointResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"#\n\x15LeaseKeepAliveRequest\x12\n\n\x02ID\x18\x01 \x01(\x03\"_\n\x16LeaseKeepAliveResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\n\n\x02ID\x18\x02 \x01(\x03\x12\x0b\n\x03TTL\x18\x03 \x01(\x03\"2\n\x16LeaseTimeToLiveRequest\x12\n\n\x02ID\x18\x01 \x01(\x03\x12\x0c\n\x04keys\x18\x02 \x01(\x08\"\x82\x01\n\x17LeaseTimeToLiveResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\n\n\x02ID\x18\x02 \x01(\x03\x12\x0b\n\x03TTL\x18\x03 \x01(\x03\x12\x12\n\ngrantedTTL\x18\x04 \x01(\x03\x12\x0c\n\x04keys\x18\x05 \x03(\x0c\"\x14\n\x12LeaseLeasesRequest\"\x19\n\x0bLeaseStatus\x12\n\n\x02ID\x18\x01 \x01(\x03\"n\n\x13LeaseLeasesResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12)\n\x06leases\x18\x02 \x03(\x0b\x32\x19.etcdserverpb.LeaseStatus\"[\n\x06Member\x12\n\n\x02ID\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08peerURLs\x18\x03 \x03(\t\x12\x12\n\nclientURLs\x18\x04 \x03(\t\x12\x11\n\tisLearner\x18\x05 \x01(\x08\"7\n\x10MemberAddRequest\x12\x10\n\x08peerURLs\x18\x01 \x03(\t\x12\x11\n\tisLearner\x18\x02 \x01(\x08\"\x8e\x01\n\x11MemberAddResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12$\n\x06member\x18\x02 \x01(\x0b\x32\x14.etcdserverpb.Member\x12%\n\x07members\x18\x03 \x03(\x0b\x32\x14.etcdserverpb.Member\"!\n\x13MemberRemoveRequest\x12\n\n\x02ID\x18\x01 \x01(\x04\"k\n\x14MemberRemoveResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12%\n\x07members\x18\x02 \x03(\x0b\x32\x14.etcdserverpb.Member\"3\n\x13MemberUpdateRequest\x12\n\n\x02ID\x18\x01 \x01(\x04\x12\x10\n\x08peerURLs\x18\x02 \x03(\t\"k\n\x14MemberUpdateResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12%\n\x07members\x18\x02 \x03(\x0b\x32\x14.etcdserverpb.Member\")\n\x11MemberListRequest\x12\x14\n\x0clinearizable\x18\x01 \x01(\x08\"i\n\x12MemberListResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12%\n\x07members\x18\x02 \x03(\x0b\x32\x14.etcdserverpb.Member\"\"\n\x14MemberPromoteRequest\x12\n\n\x02ID\x18\x01 \x01(\x04\"l\n\x15MemberPromoteResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12%\n\x07members\x18\x02 \x03(\x0b\x32\x14.etcdserverpb.Member\"\x13\n\x11\x44\x65\x66ragmentRequest\"B\n\x12\x44\x65\x66ragmentResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"%\n\x11MoveLeaderRequest\x12\x10\n\x08targetID\x18\x01 \x01(\x04\"B\n\x12MoveLeaderResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"\xb6\x01\n\x0c\x41larmRequest\x12\x36\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32&.etcdserverpb.AlarmRequest.AlarmAction\x12\x10\n\x08memberID\x18\x02 \x01(\x04\x12&\n\x05\x61larm\x18\x03 \x01(\x0e\x32\x17.etcdserverpb.AlarmType\"4\n\x0b\x41larmAction\x12\x07\n\x03GET\x10\x00\x12\x0c\n\x08\x41\x43TIVATE\x10\x01\x12\x0e\n\nDEACTIVATE\x10\x02\"G\n\x0b\x41larmMember\x12\x10\n\x08memberID\x18\x01 \x01(\x04\x12&\n\x05\x61larm\x18\x02 \x01(\x0e\x32\x17.etcdserverpb.AlarmType\"h\n\rAlarmResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12)\n\x06\x61larms\x18\x02 \x03(\x0b\x32\x19.etcdserverpb.AlarmMember\"\x9c\x01\n\x10\x44owngradeRequest\x12>\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32..etcdserverpb.DowngradeRequest.DowngradeAction\x12\x0f\n\x07version\x18\x02 \x01(\t\"7\n\x0f\x44owngradeAction\x12\x0c\n\x08VALIDATE\x10\x00\x12\n\n\x06\x45NABLE\x10\x01\x12\n\n\x06\x43\x41NCEL\x10\x02\"R\n\x11\x44owngradeResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x0f\n\rStatusRequest\"\xe6\x01\n\x0eStatusResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0e\n\x06\x64\x62Size\x18\x03 \x01(\x03\x12\x0e\n\x06leader\x18\x04 \x01(\x04\x12\x11\n\traftIndex\x18\x05 \x01(\x04\x12\x10\n\x08raftTerm\x18\x06 \x01(\x04\x12\x18\n\x10raftAppliedIndex\x18\x07 \x01(\x04\x12\x0e\n\x06\x65rrors\x18\x08 \x03(\t\x12\x13\n\x0b\x64\x62SizeInUse\x18\t \x01(\x03\x12\x11\n\tisLearner\x18\n \x01(\x08\"\x13\n\x11\x41uthEnableRequest\"\x14\n\x12\x41uthDisableRequest\"\x13\n\x11\x41uthStatusRequest\"5\n\x13\x41uthenticateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"u\n\x12\x41uthUserAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\'\n\x07options\x18\x03 \x01(\x0b\x32\x16.authpb.UserAddOptions\x12\x16\n\x0ehashedPassword\x18\x04 \x01(\t\"\"\n\x12\x41uthUserGetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"%\n\x15\x41uthUserDeleteRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"W\n\x1d\x41uthUserChangePasswordRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x16\n\x0ehashedPassword\x18\x03 \x01(\t\"6\n\x18\x41uthUserGrantRoleRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"7\n\x19\x41uthUserRevokeRoleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\"\"\n\x12\x41uthRoleAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\"\n\x12\x41uthRoleGetRequest\x12\x0c\n\x04role\x18\x01 \x01(\t\"\x15\n\x13\x41uthUserListRequest\"\x15\n\x13\x41uthRoleListRequest\"%\n\x15\x41uthRoleDeleteRequest\x12\x0c\n\x04role\x18\x01 \x01(\t\"P\n\x1e\x41uthRoleGrantPermissionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04perm\x18\x02 \x01(\x0b\x32\x12.authpb.Permission\"O\n\x1f\x41uthRoleRevokePermissionRequest\x12\x0c\n\x04role\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\x0c\x12\x11\n\trange_end\x18\x03 \x01(\x0c\"B\n\x12\x41uthEnableResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"C\n\x13\x41uthDisableResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"i\n\x12\x41uthStatusResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x14\n\x0c\x61uthRevision\x18\x03 \x01(\x04\"S\n\x14\x41uthenticateResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\r\n\x05token\x18\x02 \x01(\t\"C\n\x13\x41uthUserAddResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"R\n\x13\x41uthUserGetResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\r\n\x05roles\x18\x02 \x03(\t\"F\n\x16\x41uthUserDeleteResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"N\n\x1e\x41uthUserChangePasswordResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"I\n\x19\x41uthUserGrantRoleResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"J\n\x1a\x41uthUserRevokeRoleResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"C\n\x13\x41uthRoleAddResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"e\n\x13\x41uthRoleGetResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12 \n\x04perm\x18\x02 \x03(\x0b\x32\x12.authpb.Permission\"S\n\x14\x41uthRoleListResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\r\n\x05roles\x18\x02 \x03(\t\"S\n\x14\x41uthUserListResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\x12\r\n\x05users\x18\x02 \x03(\t\"F\n\x16\x41uthRoleDeleteResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"O\n\x1f\x41uthRoleGrantPermissionResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader\"P\n AuthRoleRevokePermissionResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.etcdserverpb.ResponseHeader*/\n\tAlarmType\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07NOSPACE\x10\x01\x12\x0b\n\x07\x43ORRUPT\x10\x02\x32\xe4\x03\n\x02KV\x12Y\n\x05Range\x12\x1a.etcdserverpb.RangeRequest\x1a\x1b.etcdserverpb.RangeResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v3/kv/range:\x01*\x12Q\n\x03Put\x12\x18.etcdserverpb.PutRequest\x1a\x19.etcdserverpb.PutResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v3/kv/put:\x01*\x12q\n\x0b\x44\x65leteRange\x12 .etcdserverpb.DeleteRangeRequest\x1a!.etcdserverpb.DeleteRangeResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v3/kv/deleterange:\x01*\x12Q\n\x03Txn\x12\x18.etcdserverpb.TxnRequest\x1a\x19.etcdserverpb.TxnResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v3/kv/txn:\x01*\x12j\n\x07\x43ompact\x12\x1f.etcdserverpb.CompactionRequest\x1a .etcdserverpb.CompactionResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v3/kv/compaction:\x01*2c\n\x05Watch\x12Z\n\x05Watch\x12\x1a.etcdserverpb.WatchRequest\x1a\x1b.etcdserverpb.WatchResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\"\t/v3/watch:\x01*(\x01\x30\x01\x32\xad\x05\n\x05Lease\x12k\n\nLeaseGrant\x12\x1f.etcdserverpb.LeaseGrantRequest\x1a .etcdserverpb.LeaseGrantResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v3/lease/grant:\x01*\x12\x89\x01\n\x0bLeaseRevoke\x12 .etcdserverpb.LeaseRevokeRequest\x1a!.etcdserverpb.LeaseRevokeResponse\"5\x82\xd3\xe4\x93\x02/\"\x10/v3/lease/revoke:\x01*Z\x18\"\x13/v3/kv/lease/revoke:\x01*\x12\x7f\n\x0eLeaseKeepAlive\x12#.etcdserverpb.LeaseKeepAliveRequest\x1a$.etcdserverpb.LeaseKeepAliveResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v3/lease/keepalive:\x01*(\x01\x30\x01\x12\x9d\x01\n\x0fLeaseTimeToLive\x12$.etcdserverpb.LeaseTimeToLiveRequest\x1a%.etcdserverpb.LeaseTimeToLiveResponse\"=\x82\xd3\xe4\x93\x02\x37\"\x14/v3/lease/timetolive:\x01*Z\x1c\"\x17/v3/kv/lease/timetolive:\x01*\x12\x89\x01\n\x0bLeaseLeases\x12 .etcdserverpb.LeaseLeasesRequest\x1a!.etcdserverpb.LeaseLeasesResponse\"5\x82\xd3\xe4\x93\x02/\"\x10/v3/lease/leases:\x01*Z\x18\"\x13/v3/kv/lease/leases:\x01*2\xea\x04\n\x07\x43luster\x12o\n\tMemberAdd\x12\x1e.etcdserverpb.MemberAddRequest\x1a\x1f.etcdserverpb.MemberAddResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v3/cluster/member/add:\x01*\x12{\n\x0cMemberRemove\x12!.etcdserverpb.MemberRemoveRequest\x1a\".etcdserverpb.MemberRemoveResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v3/cluster/member/remove:\x01*\x12{\n\x0cMemberUpdate\x12!.etcdserverpb.MemberUpdateRequest\x1a\".etcdserverpb.MemberUpdateResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v3/cluster/member/update:\x01*\x12s\n\nMemberList\x12\x1f.etcdserverpb.MemberListRequest\x1a .etcdserverpb.MemberListResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v3/cluster/member/list:\x01*\x12\x7f\n\rMemberPromote\x12\".etcdserverpb.MemberPromoteRequest\x1a#.etcdserverpb.MemberPromoteResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v3/cluster/member/promote:\x01*2\xfe\x06\n\x0bMaintenance\x12\x62\n\x05\x41larm\x12\x1a.etcdserverpb.AlarmRequest\x1a\x1b.etcdserverpb.AlarmResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v3/maintenance/alarm:\x01*\x12\x66\n\x06Status\x12\x1b.etcdserverpb.StatusRequest\x1a\x1c.etcdserverpb.StatusResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v3/maintenance/status:\x01*\x12v\n\nDefragment\x12\x1f.etcdserverpb.DefragmentRequest\x1a .etcdserverpb.DefragmentResponse\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v3/maintenance/defragment:\x01*\x12^\n\x04Hash\x12\x19.etcdserverpb.HashRequest\x1a\x1a.etcdserverpb.HashResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v3/maintenance/hash:\x01*\x12\x64\n\x06HashKV\x12\x1b.etcdserverpb.HashKVRequest\x1a\x1c.etcdserverpb.HashKVResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v3/maintenance/hash:\x01*\x12p\n\x08Snapshot\x12\x1d.etcdserverpb.SnapshotRequest\x1a\x1e.etcdserverpb.SnapshotResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v3/maintenance/snapshot:\x01*0\x01\x12\x7f\n\nMoveLeader\x12\x1f.etcdserverpb.MoveLeaderRequest\x1a .etcdserverpb.MoveLeaderResponse\".\x82\xd3\xe4\x93\x02(\"#/v3/maintenance/transfer-leadership:\x01*\x12r\n\tDowngrade\x12\x1e.etcdserverpb.DowngradeRequest\x1a\x1f.etcdserverpb.DowngradeResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v3/maintenance/downgrade:\x01*2\xa7\x10\n\x04\x41uth\x12k\n\nAuthEnable\x12\x1f.etcdserverpb.AuthEnableRequest\x1a .etcdserverpb.AuthEnableResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v3/auth/enable:\x01*\x12o\n\x0b\x41uthDisable\x12 .etcdserverpb.AuthDisableRequest\x1a!.etcdserverpb.AuthDisableResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v3/auth/disable:\x01*\x12k\n\nAuthStatus\x12\x1f.etcdserverpb.AuthStatusRequest\x1a .etcdserverpb.AuthStatusResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v3/auth/status:\x01*\x12w\n\x0c\x41uthenticate\x12!.etcdserverpb.AuthenticateRequest\x1a\".etcdserverpb.AuthenticateResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v3/auth/authenticate:\x01*\x12l\n\x07UserAdd\x12 .etcdserverpb.AuthUserAddRequest\x1a!.etcdserverpb.AuthUserAddResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v3/auth/user/add:\x01*\x12l\n\x07UserGet\x12 .etcdserverpb.AuthUserGetRequest\x1a!.etcdserverpb.AuthUserGetResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v3/auth/user/get:\x01*\x12p\n\x08UserList\x12!.etcdserverpb.AuthUserListRequest\x1a\".etcdserverpb.AuthUserListResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v3/auth/user/list:\x01*\x12x\n\nUserDelete\x12#.etcdserverpb.AuthUserDeleteRequest\x1a$.etcdserverpb.AuthUserDeleteResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v3/auth/user/delete:\x01*\x12\x92\x01\n\x12UserChangePassword\x12+.etcdserverpb.AuthUserChangePasswordRequest\x1a,.etcdserverpb.AuthUserChangePasswordResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v3/auth/user/changepw:\x01*\x12\x80\x01\n\rUserGrantRole\x12&.etcdserverpb.AuthUserGrantRoleRequest\x1a\'.etcdserverpb.AuthUserGrantRoleResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v3/auth/user/grant:\x01*\x12\x84\x01\n\x0eUserRevokeRole\x12\'.etcdserverpb.AuthUserRevokeRoleRequest\x1a(.etcdserverpb.AuthUserRevokeRoleResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v3/auth/user/revoke:\x01*\x12l\n\x07RoleAdd\x12 .etcdserverpb.AuthRoleAddRequest\x1a!.etcdserverpb.AuthRoleAddResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v3/auth/role/add:\x01*\x12l\n\x07RoleGet\x12 .etcdserverpb.AuthRoleGetRequest\x1a!.etcdserverpb.AuthRoleGetResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v3/auth/role/get:\x01*\x12p\n\x08RoleList\x12!.etcdserverpb.AuthRoleListRequest\x1a\".etcdserverpb.AuthRoleListResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v3/auth/role/list:\x01*\x12x\n\nRoleDelete\x12#.etcdserverpb.AuthRoleDeleteRequest\x1a$.etcdserverpb.AuthRoleDeleteResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v3/auth/role/delete:\x01*\x12\x92\x01\n\x13RoleGrantPermission\x12,.etcdserverpb.AuthRoleGrantPermissionRequest\x1a-.etcdserverpb.AuthRoleGrantPermissionResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v3/auth/role/grant:\x01*\x12\x96\x01\n\x14RoleRevokePermission\x12-.etcdserverpb.AuthRoleRevokePermissionRequest\x1a..etcdserverpb.AuthRoleRevokePermissionResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v3/auth/role/revoke:\x01*B\x08\xc8\xe2\x1e\x01\xd0\xe2\x1e\x01\x62\x06proto3')

_ALARMTYPE = DESCRIPTOR.enum_types_by_name['AlarmType']
AlarmType = enum_type_wrapper.EnumTypeWrapper(_ALARMTYPE)
NONE = 0
NOSPACE = 1
CORRUPT = 2


_RESPONSEHEADER = DESCRIPTOR.message_types_by_name['ResponseHeader']
_RANGEREQUEST = DESCRIPTOR.message_types_by_name['RangeRequest']
_RANGERESPONSE = DESCRIPTOR.message_types_by_name['RangeResponse']
_PUTREQUEST = DESCRIPTOR.message_types_by_name['PutRequest']
_PUTRESPONSE = DESCRIPTOR.message_types_by_name['PutResponse']
_DELETERANGEREQUEST = DESCRIPTOR.message_types_by_name['DeleteRangeRequest']
_DELETERANGERESPONSE = DESCRIPTOR.message_types_by_name['DeleteRangeResponse']
_REQUESTOP = DESCRIPTOR.message_types_by_name['RequestOp']
_RESPONSEOP = DESCRIPTOR.message_types_by_name['ResponseOp']
_COMPARE = DESCRIPTOR.message_types_by_name['Compare']
_TXNREQUEST = DESCRIPTOR.message_types_by_name['TxnRequest']
_TXNRESPONSE = DESCRIPTOR.message_types_by_name['TxnResponse']
_COMPACTIONREQUEST = DESCRIPTOR.message_types_by_name['CompactionRequest']
_COMPACTIONRESPONSE = DESCRIPTOR.message_types_by_name['CompactionResponse']
_HASHREQUEST = DESCRIPTOR.message_types_by_name['HashRequest']
_HASHKVREQUEST = DESCRIPTOR.message_types_by_name['HashKVRequest']
_HASHKVRESPONSE = DESCRIPTOR.message_types_by_name['HashKVResponse']
_HASHRESPONSE = DESCRIPTOR.message_types_by_name['HashResponse']
_SNAPSHOTREQUEST = DESCRIPTOR.message_types_by_name['SnapshotRequest']
_SNAPSHOTRESPONSE = DESCRIPTOR.message_types_by_name['SnapshotResponse']
_WATCHREQUEST = DESCRIPTOR.message_types_by_name['WatchRequest']
_WATCHCREATEREQUEST = DESCRIPTOR.message_types_by_name['WatchCreateRequest']
_WATCHCANCELREQUEST = DESCRIPTOR.message_types_by_name['WatchCancelRequest']
_WATCHPROGRESSREQUEST = DESCRIPTOR.message_types_by_name['WatchProgressRequest']
_WATCHRESPONSE = DESCRIPTOR.message_types_by_name['WatchResponse']
_LEASEGRANTREQUEST = DESCRIPTOR.message_types_by_name['LeaseGrantRequest']
_LEASEGRANTRESPONSE = DESCRIPTOR.message_types_by_name['LeaseGrantResponse']
_LEASEREVOKEREQUEST = DESCRIPTOR.message_types_by_name['LeaseRevokeRequest']
_LEASEREVOKERESPONSE = DESCRIPTOR.message_types_by_name['LeaseRevokeResponse']
_LEASECHECKPOINT = DESCRIPTOR.message_types_by_name['LeaseCheckpoint']
_LEASECHECKPOINTREQUEST = DESCRIPTOR.message_types_by_name['LeaseCheckpointRequest']
_LEASECHECKPOINTRESPONSE = DESCRIPTOR.message_types_by_name['LeaseCheckpointResponse']
_LEASEKEEPALIVEREQUEST = DESCRIPTOR.message_types_by_name['LeaseKeepAliveRequest']
_LEASEKEEPALIVERESPONSE = DESCRIPTOR.message_types_by_name['LeaseKeepAliveResponse']
_LEASETIMETOLIVEREQUEST = DESCRIPTOR.message_types_by_name['LeaseTimeToLiveRequest']
_LEASETIMETOLIVERESPONSE = DESCRIPTOR.message_types_by_name['LeaseTimeToLiveResponse']
_LEASELEASESREQUEST = DESCRIPTOR.message_types_by_name['LeaseLeasesRequest']
_LEASESTATUS = DESCRIPTOR.message_types_by_name['LeaseStatus']
_LEASELEASESRESPONSE = DESCRIPTOR.message_types_by_name['LeaseLeasesResponse']
_MEMBER = DESCRIPTOR.message_types_by_name['Member']
_MEMBERADDREQUEST = DESCRIPTOR.message_types_by_name['MemberAddRequest']
_MEMBERADDRESPONSE = DESCRIPTOR.message_types_by_name['MemberAddResponse']
_MEMBERREMOVEREQUEST = DESCRIPTOR.message_types_by_name['MemberRemoveRequest']
_MEMBERREMOVERESPONSE = DESCRIPTOR.message_types_by_name['MemberRemoveResponse']
_MEMBERUPDATEREQUEST = DESCRIPTOR.message_types_by_name['MemberUpdateRequest']
_MEMBERUPDATERESPONSE = DESCRIPTOR.message_types_by_name['MemberUpdateResponse']
_MEMBERLISTREQUEST = DESCRIPTOR.message_types_by_name['MemberListRequest']
_MEMBERLISTRESPONSE = DESCRIPTOR.message_types_by_name['MemberListResponse']
_MEMBERPROMOTEREQUEST = DESCRIPTOR.message_types_by_name['MemberPromoteRequest']
_MEMBERPROMOTERESPONSE = DESCRIPTOR.message_types_by_name['MemberPromoteResponse']
_DEFRAGMENTREQUEST = DESCRIPTOR.message_types_by_name['DefragmentRequest']
_DEFRAGMENTRESPONSE = DESCRIPTOR.message_types_by_name['DefragmentResponse']
_MOVELEADERREQUEST = DESCRIPTOR.message_types_by_name['MoveLeaderRequest']
_MOVELEADERRESPONSE = DESCRIPTOR.message_types_by_name['MoveLeaderResponse']
_ALARMREQUEST = DESCRIPTOR.message_types_by_name['AlarmRequest']
_ALARMMEMBER = DESCRIPTOR.message_types_by_name['AlarmMember']
_ALARMRESPONSE = DESCRIPTOR.message_types_by_name['AlarmResponse']
_DOWNGRADEREQUEST = DESCRIPTOR.message_types_by_name['DowngradeRequest']
_DOWNGRADERESPONSE = DESCRIPTOR.message_types_by_name['DowngradeResponse']
_STATUSREQUEST = DESCRIPTOR.message_types_by_name['StatusRequest']
_STATUSRESPONSE = DESCRIPTOR.message_types_by_name['StatusResponse']
_AUTHENABLEREQUEST = DESCRIPTOR.message_types_by_name['AuthEnableRequest']
_AUTHDISABLEREQUEST = DESCRIPTOR.message_types_by_name['AuthDisableRequest']
_AUTHSTATUSREQUEST = DESCRIPTOR.message_types_by_name['AuthStatusRequest']
_AUTHENTICATEREQUEST = DESCRIPTOR.message_types_by_name['AuthenticateRequest']
_AUTHUSERADDREQUEST = DESCRIPTOR.message_types_by_name['AuthUserAddRequest']
_AUTHUSERGETREQUEST = DESCRIPTOR.message_types_by_name['AuthUserGetRequest']
_AUTHUSERDELETEREQUEST = DESCRIPTOR.message_types_by_name['AuthUserDeleteRequest']
_AUTHUSERCHANGEPASSWORDREQUEST = DESCRIPTOR.message_types_by_name['AuthUserChangePasswordRequest']
_AUTHUSERGRANTROLEREQUEST = DESCRIPTOR.message_types_by_name['AuthUserGrantRoleRequest']
_AUTHUSERREVOKEROLEREQUEST = DESCRIPTOR.message_types_by_name['AuthUserRevokeRoleRequest']
_AUTHROLEADDREQUEST = DESCRIPTOR.message_types_by_name['AuthRoleAddRequest']
_AUTHROLEGETREQUEST = DESCRIPTOR.message_types_by_name['AuthRoleGetRequest']
_AUTHUSERLISTREQUEST = DESCRIPTOR.message_types_by_name['AuthUserListRequest']
_AUTHROLELISTREQUEST = DESCRIPTOR.message_types_by_name['AuthRoleListRequest']
_AUTHROLEDELETEREQUEST = DESCRIPTOR.message_types_by_name['AuthRoleDeleteRequest']
_AUTHROLEGRANTPERMISSIONREQUEST = DESCRIPTOR.message_types_by_name['AuthRoleGrantPermissionRequest']
_AUTHROLEREVOKEPERMISSIONREQUEST = DESCRIPTOR.message_types_by_name['AuthRoleRevokePermissionRequest']
_AUTHENABLERESPONSE = DESCRIPTOR.message_types_by_name['AuthEnableResponse']
_AUTHDISABLERESPONSE = DESCRIPTOR.message_types_by_name['AuthDisableResponse']
_AUTHSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['AuthStatusResponse']
_AUTHENTICATERESPONSE = DESCRIPTOR.message_types_by_name['AuthenticateResponse']
_AUTHUSERADDRESPONSE = DESCRIPTOR.message_types_by_name['AuthUserAddResponse']
_AUTHUSERGETRESPONSE = DESCRIPTOR.message_types_by_name['AuthUserGetResponse']
_AUTHUSERDELETERESPONSE = DESCRIPTOR.message_types_by_name['AuthUserDeleteResponse']
_AUTHUSERCHANGEPASSWORDRESPONSE = DESCRIPTOR.message_types_by_name['AuthUserChangePasswordResponse']
_AUTHUSERGRANTROLERESPONSE = DESCRIPTOR.message_types_by_name['AuthUserGrantRoleResponse']
_AUTHUSERREVOKEROLERESPONSE = DESCRIPTOR.message_types_by_name['AuthUserRevokeRoleResponse']
_AUTHROLEADDRESPONSE = DESCRIPTOR.message_types_by_name['AuthRoleAddResponse']
_AUTHROLEGETRESPONSE = DESCRIPTOR.message_types_by_name['AuthRoleGetResponse']
_AUTHROLELISTRESPONSE = DESCRIPTOR.message_types_by_name['AuthRoleListResponse']
_AUTHUSERLISTRESPONSE = DESCRIPTOR.message_types_by_name['AuthUserListResponse']
_AUTHROLEDELETERESPONSE = DESCRIPTOR.message_types_by_name['AuthRoleDeleteResponse']
_AUTHROLEGRANTPERMISSIONRESPONSE = DESCRIPTOR.message_types_by_name['AuthRoleGrantPermissionResponse']
_AUTHROLEREVOKEPERMISSIONRESPONSE = DESCRIPTOR.message_types_by_name['AuthRoleRevokePermissionResponse']
_RANGEREQUEST_SORTORDER = _RANGEREQUEST.enum_types_by_name['SortOrder']
_RANGEREQUEST_SORTTARGET = _RANGEREQUEST.enum_types_by_name['SortTarget']
_COMPARE_COMPARERESULT = _COMPARE.enum_types_by_name['CompareResult']
_COMPARE_COMPARETARGET = _COMPARE.enum_types_by_name['CompareTarget']
_WATCHCREATEREQUEST_FILTERTYPE = _WATCHCREATEREQUEST.enum_types_by_name['FilterType']
_ALARMREQUEST_ALARMACTION = _ALARMREQUEST.enum_types_by_name['AlarmAction']
_DOWNGRADEREQUEST_DOWNGRADEACTION = _DOWNGRADEREQUEST.enum_types_by_name['DowngradeAction']
ResponseHeader = _reflection.GeneratedProtocolMessageType('ResponseHeader', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEHEADER,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.ResponseHeader)
  })
_sym_db.RegisterMessage(ResponseHeader)

RangeRequest = _reflection.GeneratedProtocolMessageType('RangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _RANGEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.RangeRequest)
  })
_sym_db.RegisterMessage(RangeRequest)

RangeResponse = _reflection.GeneratedProtocolMessageType('RangeResponse', (_message.Message,), {
  'DESCRIPTOR' : _RANGERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.RangeResponse)
  })
_sym_db.RegisterMessage(RangeResponse)

PutRequest = _reflection.GeneratedProtocolMessageType('PutRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.PutRequest)
  })
_sym_db.RegisterMessage(PutRequest)

PutResponse = _reflection.GeneratedProtocolMessageType('PutResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUTRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.PutResponse)
  })
_sym_db.RegisterMessage(PutResponse)

DeleteRangeRequest = _reflection.GeneratedProtocolMessageType('DeleteRangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERANGEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.DeleteRangeRequest)
  })
_sym_db.RegisterMessage(DeleteRangeRequest)

DeleteRangeResponse = _reflection.GeneratedProtocolMessageType('DeleteRangeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERANGERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.DeleteRangeResponse)
  })
_sym_db.RegisterMessage(DeleteRangeResponse)

RequestOp = _reflection.GeneratedProtocolMessageType('RequestOp', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTOP,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.RequestOp)
  })
_sym_db.RegisterMessage(RequestOp)

ResponseOp = _reflection.GeneratedProtocolMessageType('ResponseOp', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEOP,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.ResponseOp)
  })
_sym_db.RegisterMessage(ResponseOp)

Compare = _reflection.GeneratedProtocolMessageType('Compare', (_message.Message,), {
  'DESCRIPTOR' : _COMPARE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.Compare)
  })
_sym_db.RegisterMessage(Compare)

TxnRequest = _reflection.GeneratedProtocolMessageType('TxnRequest', (_message.Message,), {
  'DESCRIPTOR' : _TXNREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.TxnRequest)
  })
_sym_db.RegisterMessage(TxnRequest)

TxnResponse = _reflection.GeneratedProtocolMessageType('TxnResponse', (_message.Message,), {
  'DESCRIPTOR' : _TXNRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.TxnResponse)
  })
_sym_db.RegisterMessage(TxnResponse)

CompactionRequest = _reflection.GeneratedProtocolMessageType('CompactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPACTIONREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.CompactionRequest)
  })
_sym_db.RegisterMessage(CompactionRequest)

CompactionResponse = _reflection.GeneratedProtocolMessageType('CompactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPACTIONRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.CompactionResponse)
  })
_sym_db.RegisterMessage(CompactionResponse)

HashRequest = _reflection.GeneratedProtocolMessageType('HashRequest', (_message.Message,), {
  'DESCRIPTOR' : _HASHREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.HashRequest)
  })
_sym_db.RegisterMessage(HashRequest)

HashKVRequest = _reflection.GeneratedProtocolMessageType('HashKVRequest', (_message.Message,), {
  'DESCRIPTOR' : _HASHKVREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.HashKVRequest)
  })
_sym_db.RegisterMessage(HashKVRequest)

HashKVResponse = _reflection.GeneratedProtocolMessageType('HashKVResponse', (_message.Message,), {
  'DESCRIPTOR' : _HASHKVRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.HashKVResponse)
  })
_sym_db.RegisterMessage(HashKVResponse)

HashResponse = _reflection.GeneratedProtocolMessageType('HashResponse', (_message.Message,), {
  'DESCRIPTOR' : _HASHRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.HashResponse)
  })
_sym_db.RegisterMessage(HashResponse)

SnapshotRequest = _reflection.GeneratedProtocolMessageType('SnapshotRequest', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.SnapshotRequest)
  })
_sym_db.RegisterMessage(SnapshotRequest)

SnapshotResponse = _reflection.GeneratedProtocolMessageType('SnapshotResponse', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.SnapshotResponse)
  })
_sym_db.RegisterMessage(SnapshotResponse)

WatchRequest = _reflection.GeneratedProtocolMessageType('WatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.WatchRequest)
  })
_sym_db.RegisterMessage(WatchRequest)

WatchCreateRequest = _reflection.GeneratedProtocolMessageType('WatchCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHCREATEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.WatchCreateRequest)
  })
_sym_db.RegisterMessage(WatchCreateRequest)

WatchCancelRequest = _reflection.GeneratedProtocolMessageType('WatchCancelRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHCANCELREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.WatchCancelRequest)
  })
_sym_db.RegisterMessage(WatchCancelRequest)

WatchProgressRequest = _reflection.GeneratedProtocolMessageType('WatchProgressRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHPROGRESSREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.WatchProgressRequest)
  })
_sym_db.RegisterMessage(WatchProgressRequest)

WatchResponse = _reflection.GeneratedProtocolMessageType('WatchResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.WatchResponse)
  })
_sym_db.RegisterMessage(WatchResponse)

LeaseGrantRequest = _reflection.GeneratedProtocolMessageType('LeaseGrantRequest', (_message.Message,), {
  'DESCRIPTOR' : _LEASEGRANTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseGrantRequest)
  })
_sym_db.RegisterMessage(LeaseGrantRequest)

LeaseGrantResponse = _reflection.GeneratedProtocolMessageType('LeaseGrantResponse', (_message.Message,), {
  'DESCRIPTOR' : _LEASEGRANTRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseGrantResponse)
  })
_sym_db.RegisterMessage(LeaseGrantResponse)

LeaseRevokeRequest = _reflection.GeneratedProtocolMessageType('LeaseRevokeRequest', (_message.Message,), {
  'DESCRIPTOR' : _LEASEREVOKEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseRevokeRequest)
  })
_sym_db.RegisterMessage(LeaseRevokeRequest)

LeaseRevokeResponse = _reflection.GeneratedProtocolMessageType('LeaseRevokeResponse', (_message.Message,), {
  'DESCRIPTOR' : _LEASEREVOKERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseRevokeResponse)
  })
_sym_db.RegisterMessage(LeaseRevokeResponse)

LeaseCheckpoint = _reflection.GeneratedProtocolMessageType('LeaseCheckpoint', (_message.Message,), {
  'DESCRIPTOR' : _LEASECHECKPOINT,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseCheckpoint)
  })
_sym_db.RegisterMessage(LeaseCheckpoint)

LeaseCheckpointRequest = _reflection.GeneratedProtocolMessageType('LeaseCheckpointRequest', (_message.Message,), {
  'DESCRIPTOR' : _LEASECHECKPOINTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseCheckpointRequest)
  })
_sym_db.RegisterMessage(LeaseCheckpointRequest)

LeaseCheckpointResponse = _reflection.GeneratedProtocolMessageType('LeaseCheckpointResponse', (_message.Message,), {
  'DESCRIPTOR' : _LEASECHECKPOINTRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseCheckpointResponse)
  })
_sym_db.RegisterMessage(LeaseCheckpointResponse)

LeaseKeepAliveRequest = _reflection.GeneratedProtocolMessageType('LeaseKeepAliveRequest', (_message.Message,), {
  'DESCRIPTOR' : _LEASEKEEPALIVEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseKeepAliveRequest)
  })
_sym_db.RegisterMessage(LeaseKeepAliveRequest)

LeaseKeepAliveResponse = _reflection.GeneratedProtocolMessageType('LeaseKeepAliveResponse', (_message.Message,), {
  'DESCRIPTOR' : _LEASEKEEPALIVERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseKeepAliveResponse)
  })
_sym_db.RegisterMessage(LeaseKeepAliveResponse)

LeaseTimeToLiveRequest = _reflection.GeneratedProtocolMessageType('LeaseTimeToLiveRequest', (_message.Message,), {
  'DESCRIPTOR' : _LEASETIMETOLIVEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseTimeToLiveRequest)
  })
_sym_db.RegisterMessage(LeaseTimeToLiveRequest)

LeaseTimeToLiveResponse = _reflection.GeneratedProtocolMessageType('LeaseTimeToLiveResponse', (_message.Message,), {
  'DESCRIPTOR' : _LEASETIMETOLIVERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseTimeToLiveResponse)
  })
_sym_db.RegisterMessage(LeaseTimeToLiveResponse)

LeaseLeasesRequest = _reflection.GeneratedProtocolMessageType('LeaseLeasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LEASELEASESREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseLeasesRequest)
  })
_sym_db.RegisterMessage(LeaseLeasesRequest)

LeaseStatus = _reflection.GeneratedProtocolMessageType('LeaseStatus', (_message.Message,), {
  'DESCRIPTOR' : _LEASESTATUS,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseStatus)
  })
_sym_db.RegisterMessage(LeaseStatus)

LeaseLeasesResponse = _reflection.GeneratedProtocolMessageType('LeaseLeasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LEASELEASESRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.LeaseLeasesResponse)
  })
_sym_db.RegisterMessage(LeaseLeasesResponse)

Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), {
  'DESCRIPTOR' : _MEMBER,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.Member)
  })
_sym_db.RegisterMessage(Member)

MemberAddRequest = _reflection.GeneratedProtocolMessageType('MemberAddRequest', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERADDREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberAddRequest)
  })
_sym_db.RegisterMessage(MemberAddRequest)

MemberAddResponse = _reflection.GeneratedProtocolMessageType('MemberAddResponse', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERADDRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberAddResponse)
  })
_sym_db.RegisterMessage(MemberAddResponse)

MemberRemoveRequest = _reflection.GeneratedProtocolMessageType('MemberRemoveRequest', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERREMOVEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberRemoveRequest)
  })
_sym_db.RegisterMessage(MemberRemoveRequest)

MemberRemoveResponse = _reflection.GeneratedProtocolMessageType('MemberRemoveResponse', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERREMOVERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberRemoveResponse)
  })
_sym_db.RegisterMessage(MemberRemoveResponse)

MemberUpdateRequest = _reflection.GeneratedProtocolMessageType('MemberUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERUPDATEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberUpdateRequest)
  })
_sym_db.RegisterMessage(MemberUpdateRequest)

MemberUpdateResponse = _reflection.GeneratedProtocolMessageType('MemberUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERUPDATERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberUpdateResponse)
  })
_sym_db.RegisterMessage(MemberUpdateResponse)

MemberListRequest = _reflection.GeneratedProtocolMessageType('MemberListRequest', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERLISTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberListRequest)
  })
_sym_db.RegisterMessage(MemberListRequest)

MemberListResponse = _reflection.GeneratedProtocolMessageType('MemberListResponse', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERLISTRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberListResponse)
  })
_sym_db.RegisterMessage(MemberListResponse)

MemberPromoteRequest = _reflection.GeneratedProtocolMessageType('MemberPromoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERPROMOTEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberPromoteRequest)
  })
_sym_db.RegisterMessage(MemberPromoteRequest)

MemberPromoteResponse = _reflection.GeneratedProtocolMessageType('MemberPromoteResponse', (_message.Message,), {
  'DESCRIPTOR' : _MEMBERPROMOTERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MemberPromoteResponse)
  })
_sym_db.RegisterMessage(MemberPromoteResponse)

DefragmentRequest = _reflection.GeneratedProtocolMessageType('DefragmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEFRAGMENTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.DefragmentRequest)
  })
_sym_db.RegisterMessage(DefragmentRequest)

DefragmentResponse = _reflection.GeneratedProtocolMessageType('DefragmentResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEFRAGMENTRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.DefragmentResponse)
  })
_sym_db.RegisterMessage(DefragmentResponse)

MoveLeaderRequest = _reflection.GeneratedProtocolMessageType('MoveLeaderRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVELEADERREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MoveLeaderRequest)
  })
_sym_db.RegisterMessage(MoveLeaderRequest)

MoveLeaderResponse = _reflection.GeneratedProtocolMessageType('MoveLeaderResponse', (_message.Message,), {
  'DESCRIPTOR' : _MOVELEADERRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.MoveLeaderResponse)
  })
_sym_db.RegisterMessage(MoveLeaderResponse)

AlarmRequest = _reflection.GeneratedProtocolMessageType('AlarmRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALARMREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AlarmRequest)
  })
_sym_db.RegisterMessage(AlarmRequest)

AlarmMember = _reflection.GeneratedProtocolMessageType('AlarmMember', (_message.Message,), {
  'DESCRIPTOR' : _ALARMMEMBER,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AlarmMember)
  })
_sym_db.RegisterMessage(AlarmMember)

AlarmResponse = _reflection.GeneratedProtocolMessageType('AlarmResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALARMRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AlarmResponse)
  })
_sym_db.RegisterMessage(AlarmResponse)

DowngradeRequest = _reflection.GeneratedProtocolMessageType('DowngradeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNGRADEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.DowngradeRequest)
  })
_sym_db.RegisterMessage(DowngradeRequest)

DowngradeResponse = _reflection.GeneratedProtocolMessageType('DowngradeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNGRADERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.DowngradeResponse)
  })
_sym_db.RegisterMessage(DowngradeResponse)

StatusRequest = _reflection.GeneratedProtocolMessageType('StatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATUSREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.StatusRequest)
  })
_sym_db.RegisterMessage(StatusRequest)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATUSRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.StatusResponse)
  })
_sym_db.RegisterMessage(StatusResponse)

AuthEnableRequest = _reflection.GeneratedProtocolMessageType('AuthEnableRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENABLEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthEnableRequest)
  })
_sym_db.RegisterMessage(AuthEnableRequest)

AuthDisableRequest = _reflection.GeneratedProtocolMessageType('AuthDisableRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHDISABLEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthDisableRequest)
  })
_sym_db.RegisterMessage(AuthDisableRequest)

AuthStatusRequest = _reflection.GeneratedProtocolMessageType('AuthStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHSTATUSREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthStatusRequest)
  })
_sym_db.RegisterMessage(AuthStatusRequest)

AuthenticateRequest = _reflection.GeneratedProtocolMessageType('AuthenticateRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthenticateRequest)
  })
_sym_db.RegisterMessage(AuthenticateRequest)

AuthUserAddRequest = _reflection.GeneratedProtocolMessageType('AuthUserAddRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERADDREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserAddRequest)
  })
_sym_db.RegisterMessage(AuthUserAddRequest)

AuthUserGetRequest = _reflection.GeneratedProtocolMessageType('AuthUserGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERGETREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserGetRequest)
  })
_sym_db.RegisterMessage(AuthUserGetRequest)

AuthUserDeleteRequest = _reflection.GeneratedProtocolMessageType('AuthUserDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERDELETEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserDeleteRequest)
  })
_sym_db.RegisterMessage(AuthUserDeleteRequest)

AuthUserChangePasswordRequest = _reflection.GeneratedProtocolMessageType('AuthUserChangePasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERCHANGEPASSWORDREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserChangePasswordRequest)
  })
_sym_db.RegisterMessage(AuthUserChangePasswordRequest)

AuthUserGrantRoleRequest = _reflection.GeneratedProtocolMessageType('AuthUserGrantRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERGRANTROLEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserGrantRoleRequest)
  })
_sym_db.RegisterMessage(AuthUserGrantRoleRequest)

AuthUserRevokeRoleRequest = _reflection.GeneratedProtocolMessageType('AuthUserRevokeRoleRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERREVOKEROLEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserRevokeRoleRequest)
  })
_sym_db.RegisterMessage(AuthUserRevokeRoleRequest)

AuthRoleAddRequest = _reflection.GeneratedProtocolMessageType('AuthRoleAddRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLEADDREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleAddRequest)
  })
_sym_db.RegisterMessage(AuthRoleAddRequest)

AuthRoleGetRequest = _reflection.GeneratedProtocolMessageType('AuthRoleGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLEGETREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleGetRequest)
  })
_sym_db.RegisterMessage(AuthRoleGetRequest)

AuthUserListRequest = _reflection.GeneratedProtocolMessageType('AuthUserListRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERLISTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserListRequest)
  })
_sym_db.RegisterMessage(AuthUserListRequest)

AuthRoleListRequest = _reflection.GeneratedProtocolMessageType('AuthRoleListRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLELISTREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleListRequest)
  })
_sym_db.RegisterMessage(AuthRoleListRequest)

AuthRoleDeleteRequest = _reflection.GeneratedProtocolMessageType('AuthRoleDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLEDELETEREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleDeleteRequest)
  })
_sym_db.RegisterMessage(AuthRoleDeleteRequest)

AuthRoleGrantPermissionRequest = _reflection.GeneratedProtocolMessageType('AuthRoleGrantPermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLEGRANTPERMISSIONREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleGrantPermissionRequest)
  })
_sym_db.RegisterMessage(AuthRoleGrantPermissionRequest)

AuthRoleRevokePermissionRequest = _reflection.GeneratedProtocolMessageType('AuthRoleRevokePermissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLEREVOKEPERMISSIONREQUEST,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleRevokePermissionRequest)
  })
_sym_db.RegisterMessage(AuthRoleRevokePermissionRequest)

AuthEnableResponse = _reflection.GeneratedProtocolMessageType('AuthEnableResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENABLERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthEnableResponse)
  })
_sym_db.RegisterMessage(AuthEnableResponse)

AuthDisableResponse = _reflection.GeneratedProtocolMessageType('AuthDisableResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHDISABLERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthDisableResponse)
  })
_sym_db.RegisterMessage(AuthDisableResponse)

AuthStatusResponse = _reflection.GeneratedProtocolMessageType('AuthStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHSTATUSRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthStatusResponse)
  })
_sym_db.RegisterMessage(AuthStatusResponse)

AuthenticateResponse = _reflection.GeneratedProtocolMessageType('AuthenticateResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHENTICATERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthenticateResponse)
  })
_sym_db.RegisterMessage(AuthenticateResponse)

AuthUserAddResponse = _reflection.GeneratedProtocolMessageType('AuthUserAddResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERADDRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserAddResponse)
  })
_sym_db.RegisterMessage(AuthUserAddResponse)

AuthUserGetResponse = _reflection.GeneratedProtocolMessageType('AuthUserGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERGETRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserGetResponse)
  })
_sym_db.RegisterMessage(AuthUserGetResponse)

AuthUserDeleteResponse = _reflection.GeneratedProtocolMessageType('AuthUserDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERDELETERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserDeleteResponse)
  })
_sym_db.RegisterMessage(AuthUserDeleteResponse)

AuthUserChangePasswordResponse = _reflection.GeneratedProtocolMessageType('AuthUserChangePasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERCHANGEPASSWORDRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserChangePasswordResponse)
  })
_sym_db.RegisterMessage(AuthUserChangePasswordResponse)

AuthUserGrantRoleResponse = _reflection.GeneratedProtocolMessageType('AuthUserGrantRoleResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERGRANTROLERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserGrantRoleResponse)
  })
_sym_db.RegisterMessage(AuthUserGrantRoleResponse)

AuthUserRevokeRoleResponse = _reflection.GeneratedProtocolMessageType('AuthUserRevokeRoleResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERREVOKEROLERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserRevokeRoleResponse)
  })
_sym_db.RegisterMessage(AuthUserRevokeRoleResponse)

AuthRoleAddResponse = _reflection.GeneratedProtocolMessageType('AuthRoleAddResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLEADDRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleAddResponse)
  })
_sym_db.RegisterMessage(AuthRoleAddResponse)

AuthRoleGetResponse = _reflection.GeneratedProtocolMessageType('AuthRoleGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLEGETRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleGetResponse)
  })
_sym_db.RegisterMessage(AuthRoleGetResponse)

AuthRoleListResponse = _reflection.GeneratedProtocolMessageType('AuthRoleListResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLELISTRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleListResponse)
  })
_sym_db.RegisterMessage(AuthRoleListResponse)

AuthUserListResponse = _reflection.GeneratedProtocolMessageType('AuthUserListResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHUSERLISTRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthUserListResponse)
  })
_sym_db.RegisterMessage(AuthUserListResponse)

AuthRoleDeleteResponse = _reflection.GeneratedProtocolMessageType('AuthRoleDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLEDELETERESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleDeleteResponse)
  })
_sym_db.RegisterMessage(AuthRoleDeleteResponse)

AuthRoleGrantPermissionResponse = _reflection.GeneratedProtocolMessageType('AuthRoleGrantPermissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLEGRANTPERMISSIONRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleGrantPermissionResponse)
  })
_sym_db.RegisterMessage(AuthRoleGrantPermissionResponse)

AuthRoleRevokePermissionResponse = _reflection.GeneratedProtocolMessageType('AuthRoleRevokePermissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _AUTHROLEREVOKEPERMISSIONRESPONSE,
  '__module__' : 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.AuthRoleRevokePermissionResponse)
  })
_sym_db.RegisterMessage(AuthRoleRevokePermissionResponse)

_KV = DESCRIPTOR.services_by_name['KV']
_WATCH = DESCRIPTOR.services_by_name['Watch']
_LEASE = DESCRIPTOR.services_by_name['Lease']
_CLUSTER = DESCRIPTOR.services_by_name['Cluster']
_MAINTENANCE = DESCRIPTOR.services_by_name['Maintenance']
_AUTH = DESCRIPTOR.services_by_name['Auth']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\310\342\036\001\320\342\036\001'
  _KV.methods_by_name['Range']._options = None
  _KV.methods_by_name['Range']._serialized_options = b'\202\323\344\223\002\021\"\014/v3/kv/range:\001*'
  _KV.methods_by_name['Put']._options = None
  _KV.methods_by_name['Put']._serialized_options = b'\202\323\344\223\002\017\"\n/v3/kv/put:\001*'
  _KV.methods_by_name['DeleteRange']._options = None
  _KV.methods_by_name['DeleteRange']._serialized_options = b'\202\323\344\223\002\027\"\022/v3/kv/deleterange:\001*'
  _KV.methods_by_name['Txn']._options = None
  _KV.methods_by_name['Txn']._serialized_options = b'\202\323\344\223\002\017\"\n/v3/kv/txn:\001*'
  _KV.methods_by_name['Compact']._options = None
  _KV.methods_by_name['Compact']._serialized_options = b'\202\323\344\223\002\026\"\021/v3/kv/compaction:\001*'
  _WATCH.methods_by_name['Watch']._options = None
  _WATCH.methods_by_name['Watch']._serialized_options = b'\202\323\344\223\002\016\"\t/v3/watch:\001*'
  _LEASE.methods_by_name['LeaseGrant']._options = None
  _LEASE.methods_by_name['LeaseGrant']._serialized_options = b'\202\323\344\223\002\024\"\017/v3/lease/grant:\001*'
  _LEASE.methods_by_name['LeaseRevoke']._options = None
  _LEASE.methods_by_name['LeaseRevoke']._serialized_options = b'\202\323\344\223\002/\"\020/v3/lease/revoke:\001*Z\030\"\023/v3/kv/lease/revoke:\001*'
  _LEASE.methods_by_name['LeaseKeepAlive']._options = None
  _LEASE.methods_by_name['LeaseKeepAlive']._serialized_options = b'\202\323\344\223\002\030\"\023/v3/lease/keepalive:\001*'
  _LEASE.methods_by_name['LeaseTimeToLive']._options = None
  _LEASE.methods_by_name['LeaseTimeToLive']._serialized_options = b'\202\323\344\223\0027\"\024/v3/lease/timetolive:\001*Z\034\"\027/v3/kv/lease/timetolive:\001*'
  _LEASE.methods_by_name['LeaseLeases']._options = None
  _LEASE.methods_by_name['LeaseLeases']._serialized_options = b'\202\323\344\223\002/\"\020/v3/lease/leases:\001*Z\030\"\023/v3/kv/lease/leases:\001*'
  _CLUSTER.methods_by_name['MemberAdd']._options = None
  _CLUSTER.methods_by_name['MemberAdd']._serialized_options = b'\202\323\344\223\002\033\"\026/v3/cluster/member/add:\001*'
  _CLUSTER.methods_by_name['MemberRemove']._options = None
  _CLUSTER.methods_by_name['MemberRemove']._serialized_options = b'\202\323\344\223\002\036\"\031/v3/cluster/member/remove:\001*'
  _CLUSTER.methods_by_name['MemberUpdate']._options = None
  _CLUSTER.methods_by_name['MemberUpdate']._serialized_options = b'\202\323\344\223\002\036\"\031/v3/cluster/member/update:\001*'
  _CLUSTER.methods_by_name['MemberList']._options = None
  _CLUSTER.methods_by_name['MemberList']._serialized_options = b'\202\323\344\223\002\034\"\027/v3/cluster/member/list:\001*'
  _CLUSTER.methods_by_name['MemberPromote']._options = None
  _CLUSTER.methods_by_name['MemberPromote']._serialized_options = b'\202\323\344\223\002\037\"\032/v3/cluster/member/promote:\001*'
  _MAINTENANCE.methods_by_name['Alarm']._options = None
  _MAINTENANCE.methods_by_name['Alarm']._serialized_options = b'\202\323\344\223\002\032\"\025/v3/maintenance/alarm:\001*'
  _MAINTENANCE.methods_by_name['Status']._options = None
  _MAINTENANCE.methods_by_name['Status']._serialized_options = b'\202\323\344\223\002\033\"\026/v3/maintenance/status:\001*'
  _MAINTENANCE.methods_by_name['Defragment']._options = None
  _MAINTENANCE.methods_by_name['Defragment']._serialized_options = b'\202\323\344\223\002\037\"\032/v3/maintenance/defragment:\001*'
  _MAINTENANCE.methods_by_name['Hash']._options = None
  _MAINTENANCE.methods_by_name['Hash']._serialized_options = b'\202\323\344\223\002\031\"\024/v3/maintenance/hash:\001*'
  _MAINTENANCE.methods_by_name['HashKV']._options = None
  _MAINTENANCE.methods_by_name['HashKV']._serialized_options = b'\202\323\344\223\002\031\"\024/v3/maintenance/hash:\001*'
  _MAINTENANCE.methods_by_name['Snapshot']._options = None
  _MAINTENANCE.methods_by_name['Snapshot']._serialized_options = b'\202\323\344\223\002\035\"\030/v3/maintenance/snapshot:\001*'
  _MAINTENANCE.methods_by_name['MoveLeader']._options = None
  _MAINTENANCE.methods_by_name['MoveLeader']._serialized_options = b'\202\323\344\223\002(\"#/v3/maintenance/transfer-leadership:\001*'
  _MAINTENANCE.methods_by_name['Downgrade']._options = None
  _MAINTENANCE.methods_by_name['Downgrade']._serialized_options = b'\202\323\344\223\002\036\"\031/v3/maintenance/downgrade:\001*'
  _AUTH.methods_by_name['AuthEnable']._options = None
  _AUTH.methods_by_name['AuthEnable']._serialized_options = b'\202\323\344\223\002\024\"\017/v3/auth/enable:\001*'
  _AUTH.methods_by_name['AuthDisable']._options = None
  _AUTH.methods_by_name['AuthDisable']._serialized_options = b'\202\323\344\223\002\025\"\020/v3/auth/disable:\001*'
  _AUTH.methods_by_name['AuthStatus']._options = None
  _AUTH.methods_by_name['AuthStatus']._serialized_options = b'\202\323\344\223\002\024\"\017/v3/auth/status:\001*'
  _AUTH.methods_by_name['Authenticate']._options = None
  _AUTH.methods_by_name['Authenticate']._serialized_options = b'\202\323\344\223\002\032\"\025/v3/auth/authenticate:\001*'
  _AUTH.methods_by_name['UserAdd']._options = None
  _AUTH.methods_by_name['UserAdd']._serialized_options = b'\202\323\344\223\002\026\"\021/v3/auth/user/add:\001*'
  _AUTH.methods_by_name['UserGet']._options = None
  _AUTH.methods_by_name['UserGet']._serialized_options = b'\202\323\344\223\002\026\"\021/v3/auth/user/get:\001*'
  _AUTH.methods_by_name['UserList']._options = None
  _AUTH.methods_by_name['UserList']._serialized_options = b'\202\323\344\223\002\027\"\022/v3/auth/user/list:\001*'
  _AUTH.methods_by_name['UserDelete']._options = None
  _AUTH.methods_by_name['UserDelete']._serialized_options = b'\202\323\344\223\002\031\"\024/v3/auth/user/delete:\001*'
  _AUTH.methods_by_name['UserChangePassword']._options = None
  _AUTH.methods_by_name['UserChangePassword']._serialized_options = b'\202\323\344\223\002\033\"\026/v3/auth/user/changepw:\001*'
  _AUTH.methods_by_name['UserGrantRole']._options = None
  _AUTH.methods_by_name['UserGrantRole']._serialized_options = b'\202\323\344\223\002\030\"\023/v3/auth/user/grant:\001*'
  _AUTH.methods_by_name['UserRevokeRole']._options = None
  _AUTH.methods_by_name['UserRevokeRole']._serialized_options = b'\202\323\344\223\002\031\"\024/v3/auth/user/revoke:\001*'
  _AUTH.methods_by_name['RoleAdd']._options = None
  _AUTH.methods_by_name['RoleAdd']._serialized_options = b'\202\323\344\223\002\026\"\021/v3/auth/role/add:\001*'
  _AUTH.methods_by_name['RoleGet']._options = None
  _AUTH.methods_by_name['RoleGet']._serialized_options = b'\202\323\344\223\002\026\"\021/v3/auth/role/get:\001*'
  _AUTH.methods_by_name['RoleList']._options = None
  _AUTH.methods_by_name['RoleList']._serialized_options = b'\202\323\344\223\002\027\"\022/v3/auth/role/list:\001*'
  _AUTH.methods_by_name['RoleDelete']._options = None
  _AUTH.methods_by_name['RoleDelete']._serialized_options = b'\202\323\344\223\002\031\"\024/v3/auth/role/delete:\001*'
  _AUTH.methods_by_name['RoleGrantPermission']._options = None
  _AUTH.methods_by_name['RoleGrantPermission']._serialized_options = b'\202\323\344\223\002\030\"\023/v3/auth/role/grant:\001*'
  _AUTH.methods_by_name['RoleRevokePermission']._options = None
  _AUTH.methods_by_name['RoleRevokePermission']._serialized_options = b'\202\323\344\223\002\031\"\024/v3/auth/role/revoke:\001*'
  _ALARMTYPE._serialized_start=8681
  _ALARMTYPE._serialized_end=8728
  _RESPONSEHEADER._serialized_start=80
  _RESPONSEHEADER._serialized_end=172
  _RANGEREQUEST._serialized_start=175
  _RANGEREQUEST._serialized_end=659
  _RANGEREQUEST_SORTORDER._serialized_start=545
  _RANGEREQUEST_SORTORDER._serialized_end=591
  _RANGEREQUEST_SORTTARGET._serialized_start=593
  _RANGEREQUEST_SORTTARGET._serialized_end=659
  _RANGERESPONSE._serialized_start=661
  _RANGERESPONSE._serialized_end=782
  _PUTREQUEST._serialized_start=784
  _PUTREQUEST._serialized_end=900
  _PUTRESPONSE._serialized_start=902
  _PUTRESPONSE._serialized_end=996
  _DELETERANGEREQUEST._serialized_start=998
  _DELETERANGEREQUEST._serialized_end=1067
  _DELETERANGERESPONSE._serialized_start=1069
  _DELETERANGERESPONSE._serialized_end=1189
  _REQUESTOP._serialized_start=1192
  _REQUESTOP._serialized_end=1431
  _RESPONSEOP._serialized_start=1434
  _RESPONSEOP._serialized_end=1683
  _COMPARE._serialized_start=1686
  _COMPARE._serialized_end=2092
  _COMPARE_COMPARERESULT._serialized_start=1939
  _COMPARE_COMPARERESULT._serialized_end=2003
  _COMPARE_COMPARETARGET._serialized_start=2005
  _COMPARE_COMPARETARGET._serialized_end=2076
  _TXNREQUEST._serialized_start=2095
  _TXNREQUEST._serialized_end=2231
  _TXNRESPONSE._serialized_start=2233
  _TXNRESPONSE._serialized_end=2356
  _COMPACTIONREQUEST._serialized_start=2358
  _COMPACTIONREQUEST._serialized_end=2413
  _COMPACTIONRESPONSE._serialized_start=2415
  _COMPACTIONRESPONSE._serialized_end=2481
  _HASHREQUEST._serialized_start=2483
  _HASHREQUEST._serialized_end=2496
  _HASHKVREQUEST._serialized_start=2498
  _HASHKVREQUEST._serialized_end=2531
  _HASHKVRESPONSE._serialized_start=2533
  _HASHKVRESPONSE._serialized_end=2635
  _HASHRESPONSE._serialized_start=2637
  _HASHRESPONSE._serialized_end=2711
  _SNAPSHOTREQUEST._serialized_start=2713
  _SNAPSHOTREQUEST._serialized_end=2730
  _SNAPSHOTRESPONSE._serialized_start=2732
  _SNAPSHOTRESPONSE._serialized_end=2835
  _WATCHREQUEST._serialized_start=2838
  _WATCHREQUEST._serialized_end=3053
  _WATCHCREATEREQUEST._serialized_start=3056
  _WATCHCREATEREQUEST._serialized_end=3311
  _WATCHCREATEREQUEST_FILTERTYPE._serialized_start=3274
  _WATCHCREATEREQUEST_FILTERTYPE._serialized_end=3311
  _WATCHCANCELREQUEST._serialized_start=3313
  _WATCHCANCELREQUEST._serialized_end=3351
  _WATCHPROGRESSREQUEST._serialized_start=3353
  _WATCHPROGRESSREQUEST._serialized_end=3375
  _WATCHRESPONSE._serialized_start=3378
  _WATCHRESPONSE._serialized_end=3590
  _LEASEGRANTREQUEST._serialized_start=3592
  _LEASEGRANTREQUEST._serialized_end=3636
  _LEASEGRANTRESPONSE._serialized_start=3638
  _LEASEGRANTRESPONSE._serialized_end=3744
  _LEASEREVOKEREQUEST._serialized_start=3746
  _LEASEREVOKEREQUEST._serialized_end=3778
  _LEASEREVOKERESPONSE._serialized_start=3780
  _LEASEREVOKERESPONSE._serialized_end=3847
  _LEASECHECKPOINT._serialized_start=3849
  _LEASECHECKPOINT._serialized_end=3901
  _LEASECHECKPOINTREQUEST._serialized_start=3903
  _LEASECHECKPOINTREQUEST._serialized_end=3979
  _LEASECHECKPOINTRESPONSE._serialized_start=3981
  _LEASECHECKPOINTRESPONSE._serialized_end=4052
  _LEASEKEEPALIVEREQUEST._serialized_start=4054
  _LEASEKEEPALIVEREQUEST._serialized_end=4089
  _LEASEKEEPALIVERESPONSE._serialized_start=4091
  _LEASEKEEPALIVERESPONSE._serialized_end=4186
  _LEASETIMETOLIVEREQUEST._serialized_start=4188
  _LEASETIMETOLIVEREQUEST._serialized_end=4238
  _LEASETIMETOLIVERESPONSE._serialized_start=4241
  _LEASETIMETOLIVERESPONSE._serialized_end=4371
  _LEASELEASESREQUEST._serialized_start=4373
  _LEASELEASESREQUEST._serialized_end=4393
  _LEASESTATUS._serialized_start=4395
  _LEASESTATUS._serialized_end=4420
  _LEASELEASESRESPONSE._serialized_start=4422
  _LEASELEASESRESPONSE._serialized_end=4532
  _MEMBER._serialized_start=4534
  _MEMBER._serialized_end=4625
  _MEMBERADDREQUEST._serialized_start=4627
  _MEMBERADDREQUEST._serialized_end=4682
  _MEMBERADDRESPONSE._serialized_start=4685
  _MEMBERADDRESPONSE._serialized_end=4827
  _MEMBERREMOVEREQUEST._serialized_start=4829
  _MEMBERREMOVEREQUEST._serialized_end=4862
  _MEMBERREMOVERESPONSE._serialized_start=4864
  _MEMBERREMOVERESPONSE._serialized_end=4971
  _MEMBERUPDATEREQUEST._serialized_start=4973
  _MEMBERUPDATEREQUEST._serialized_end=5024
  _MEMBERUPDATERESPONSE._serialized_start=5026
  _MEMBERUPDATERESPONSE._serialized_end=5133
  _MEMBERLISTREQUEST._serialized_start=5135
  _MEMBERLISTREQUEST._serialized_end=5176
  _MEMBERLISTRESPONSE._serialized_start=5178
  _MEMBERLISTRESPONSE._serialized_end=5283
  _MEMBERPROMOTEREQUEST._serialized_start=5285
  _MEMBERPROMOTEREQUEST._serialized_end=5319
  _MEMBERPROMOTERESPONSE._serialized_start=5321
  _MEMBERPROMOTERESPONSE._serialized_end=5429
  _DEFRAGMENTREQUEST._serialized_start=5431
  _DEFRAGMENTREQUEST._serialized_end=5450
  _DEFRAGMENTRESPONSE._serialized_start=5452
  _DEFRAGMENTRESPONSE._serialized_end=5518
  _MOVELEADERREQUEST._serialized_start=5520
  _MOVELEADERREQUEST._serialized_end=5557
  _MOVELEADERRESPONSE._serialized_start=5559
  _MOVELEADERRESPONSE._serialized_end=5625
  _ALARMREQUEST._serialized_start=5628
  _ALARMREQUEST._serialized_end=5810
  _ALARMREQUEST_ALARMACTION._serialized_start=5758
  _ALARMREQUEST_ALARMACTION._serialized_end=5810
  _ALARMMEMBER._serialized_start=5812
  _ALARMMEMBER._serialized_end=5883
  _ALARMRESPONSE._serialized_start=5885
  _ALARMRESPONSE._serialized_end=5989
  _DOWNGRADEREQUEST._serialized_start=5992
  _DOWNGRADEREQUEST._serialized_end=6148
  _DOWNGRADEREQUEST_DOWNGRADEACTION._serialized_start=6093
  _DOWNGRADEREQUEST_DOWNGRADEACTION._serialized_end=6148
  _DOWNGRADERESPONSE._serialized_start=6150
  _DOWNGRADERESPONSE._serialized_end=6232
  _STATUSREQUEST._serialized_start=6234
  _STATUSREQUEST._serialized_end=6249
  _STATUSRESPONSE._serialized_start=6252
  _STATUSRESPONSE._serialized_end=6482
  _AUTHENABLEREQUEST._serialized_start=6484
  _AUTHENABLEREQUEST._serialized_end=6503
  _AUTHDISABLEREQUEST._serialized_start=6505
  _AUTHDISABLEREQUEST._serialized_end=6525
  _AUTHSTATUSREQUEST._serialized_start=6527
  _AUTHSTATUSREQUEST._serialized_end=6546
  _AUTHENTICATEREQUEST._serialized_start=6548
  _AUTHENTICATEREQUEST._serialized_end=6601
  _AUTHUSERADDREQUEST._serialized_start=6603
  _AUTHUSERADDREQUEST._serialized_end=6720
  _AUTHUSERGETREQUEST._serialized_start=6722
  _AUTHUSERGETREQUEST._serialized_end=6756
  _AUTHUSERDELETEREQUEST._serialized_start=6758
  _AUTHUSERDELETEREQUEST._serialized_end=6795
  _AUTHUSERCHANGEPASSWORDREQUEST._serialized_start=6797
  _AUTHUSERCHANGEPASSWORDREQUEST._serialized_end=6884
  _AUTHUSERGRANTROLEREQUEST._serialized_start=6886
  _AUTHUSERGRANTROLEREQUEST._serialized_end=6940
  _AUTHUSERREVOKEROLEREQUEST._serialized_start=6942
  _AUTHUSERREVOKEROLEREQUEST._serialized_end=6997
  _AUTHROLEADDREQUEST._serialized_start=6999
  _AUTHROLEADDREQUEST._serialized_end=7033
  _AUTHROLEGETREQUEST._serialized_start=7035
  _AUTHROLEGETREQUEST._serialized_end=7069
  _AUTHUSERLISTREQUEST._serialized_start=7071
  _AUTHUSERLISTREQUEST._serialized_end=7092
  _AUTHROLELISTREQUEST._serialized_start=7094
  _AUTHROLELISTREQUEST._serialized_end=7115
  _AUTHROLEDELETEREQUEST._serialized_start=7117
  _AUTHROLEDELETEREQUEST._serialized_end=7154
  _AUTHROLEGRANTPERMISSIONREQUEST._serialized_start=7156
  _AUTHROLEGRANTPERMISSIONREQUEST._serialized_end=7236
  _AUTHROLEREVOKEPERMISSIONREQUEST._serialized_start=7238
  _AUTHROLEREVOKEPERMISSIONREQUEST._serialized_end=7317
  _AUTHENABLERESPONSE._serialized_start=7319
  _AUTHENABLERESPONSE._serialized_end=7385
  _AUTHDISABLERESPONSE._serialized_start=7387
  _AUTHDISABLERESPONSE._serialized_end=7454
  _AUTHSTATUSRESPONSE._serialized_start=7456
  _AUTHSTATUSRESPONSE._serialized_end=7561
  _AUTHENTICATERESPONSE._serialized_start=7563
  _AUTHENTICATERESPONSE._serialized_end=7646
  _AUTHUSERADDRESPONSE._serialized_start=7648
  _AUTHUSERADDRESPONSE._serialized_end=7715
  _AUTHUSERGETRESPONSE._serialized_start=7717
  _AUTHUSERGETRESPONSE._serialized_end=7799
  _AUTHUSERDELETERESPONSE._serialized_start=7801
  _AUTHUSERDELETERESPONSE._serialized_end=7871
  _AUTHUSERCHANGEPASSWORDRESPONSE._serialized_start=7873
  _AUTHUSERCHANGEPASSWORDRESPONSE._serialized_end=7951
  _AUTHUSERGRANTROLERESPONSE._serialized_start=7953
  _AUTHUSERGRANTROLERESPONSE._serialized_end=8026
  _AUTHUSERREVOKEROLERESPONSE._serialized_start=8028
  _AUTHUSERREVOKEROLERESPONSE._serialized_end=8102
  _AUTHROLEADDRESPONSE._serialized_start=8104
  _AUTHROLEADDRESPONSE._serialized_end=8171
  _AUTHROLEGETRESPONSE._serialized_start=8173
  _AUTHROLEGETRESPONSE._serialized_end=8274
  _AUTHROLELISTRESPONSE._serialized_start=8276
  _AUTHROLELISTRESPONSE._serialized_end=8359
  _AUTHUSERLISTRESPONSE._serialized_start=8361
  _AUTHUSERLISTRESPONSE._serialized_end=8444
  _AUTHROLEDELETERESPONSE._serialized_start=8446
  _AUTHROLEDELETERESPONSE._serialized_end=8516
  _AUTHROLEGRANTPERMISSIONRESPONSE._serialized_start=8518
  _AUTHROLEGRANTPERMISSIONRESPONSE._serialized_end=8597
  _AUTHROLEREVOKEPERMISSIONRESPONSE._serialized_start=8599
  _AUTHROLEREVOKEPERMISSIONRESPONSE._serialized_end=8679
  _KV._serialized_start=8731
  _KV._serialized_end=9215
  _WATCH._serialized_start=9217
  _WATCH._serialized_end=9316
  _LEASE._serialized_start=9319
  _LEASE._serialized_end=10004
  _CLUSTER._serialized_start=10007
  _CLUSTER._serialized_end=10625
  _MAINTENANCE._serialized_start=10628
  _MAINTENANCE._serialized_end=11522
  _AUTH._serialized_start=11525
  _AUTH._serialized_end=13612
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from etcetra.grpc_api import v3election_pb2 as v3election__pb2


class ElectionStub(object):
    """The election service exposes client-side election facilities as a gRPC interface.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Campaign = channel.unary_unary(
                '/v3electionpb.Election/Campaign',
                request_serializer=v3election__pb2.CampaignRequest.SerializeToString,
                response_deserializer=v3election__pb2.CampaignResponse.FromString,
                )
        self.Proclaim = channel.unary_unary(
                '/v3electionpb.Election/Proclaim',
                request_serializer=v3election__pb2.ProclaimRequest.SerializeToString,
                response_deserializer=v3election__pb2.ProclaimResponse.FromString,
                )
        self.Leader = channel.unary_unary(
                '/v3electionpb.Election/Leader',
                request_serializer=v3election__pb2.LeaderRequest.SerializeToString,
                response_deserializer=v3election__pb2.LeaderResponse.FromString,
                )
        self.Observe = channel.unary_stream(
                '/v3electionpb.Election/Observe',
                request_serializer=v3election__pb2.LeaderRequest.SerializeToString,
                response_deserializer=v3election__pb2.LeaderResponse.FromString,
                )
        self.Resign = channel.unary_unary(
                '/v3electionpb.Election/Resign',
                request_serializer=v3election__pb2.ResignRequest.SerializeToString,
                response_deserializer=v3election__pb2.ResignResponse.FromString,
                )


class ElectionServicer(object):
    """The election service exposes client-side election facilities as a gRPC interface.
    """

    def Campaign(self, request, context):
        """Campaign waits to acquire leadership in an election, returning a LeaderKey
        representing the leadership if successful. The LeaderKey can then be used
        to issue new values on the election, transactionally guard API requests on
        leadership still being held, and resign from the election.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Proclaim(self, request, context):
        """Proclaim updates the leader's posted value with a new value.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Leader(self, request, context):
        """Leader returns the current election proclamation, if any.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Observe(self, request, context):
        """Observe streams election proclamations in-order as made by the election's
        elected leaders.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Resign(self, request, context):
        """Resign releases election leadership so other campaigners may acquire
        leadership on the election.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ElectionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Campaign': grpc.unary_unary_rpc_method_handler(
                    servicer.Campaign,
                    request_deserializer=v3election__pb2.CampaignRequest.FromString,
                    response_serializer=v3election__pb2.CampaignResponse.SerializeToString,
            ),
            'Proclaim': grpc.unary_unary_rpc_method_handler(
                    servicer.Proclaim,
                    request_deserializer=v3election__pb2.ProclaimRequest.FromString,
                    response_serializer=v3election__pb2.ProclaimResponse.SerializeToString,
            ),
            'Leader': grpc.unary_unary_rpc_method_handler(
                    servicer.Leader,
                    request_deserializer=v3election__pb2.LeaderRequest.FromString,
                    response_serializer=v3election__pb2.LeaderResponse.SerializeToString,
            ),
            'Observe': grpc.unary_stream_rpc_method_handler(
                    servicer.Observe,
                    request_deserializer=v3election__pb2.LeaderRequest.FromString,
                    response_serializer=v3election__pb2.LeaderResponse.SerializeToString,
            ),
            'Resign': grpc.unary_unary_rpc_method_handler(
                    servicer.Resign,
                    request_deserializer=v3election__pb2.ResignRequest.FromString,
                    response_serializer=v3election__pb2.ResignResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v3electionpb.Election', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Election(object):
    """The election service exposes client-side election facilities as a gRPC interface.
    """

    @staticmethod
    def Campaign(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v3electionpb.Election/Campaign',
            v3election__pb2.CampaignRequest.SerializeToString,
            v3election__pb2.CampaignResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Proclaim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v3electionpb.Election/Proclaim',
            v3election__pb2.ProclaimRequest.SerializeToString,
            v3election__pb2.ProclaimResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Leader(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v3electionpb.Election/Leader',
            v3election__pb2.LeaderRequest.SerializeToString,
            v3election__pb2.LeaderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Observe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/v3electionpb.Election/Observe',
            v3election__pb2.LeaderRequest.SerializeToString,
            v3election__pb2.LeaderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Resign(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v3electionpb.Election/Resign',
            v3election__pb2.ResignRequest.SerializeToString,
            v3election__pb2.ResignResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: etcdserver.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from etcetra.grpc_api import gogo_pb2 as gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x65tcdserver.proto\x12\x0c\x65tcdserverpb\x1a\ngogo.proto\"\xff\x02\n\x07Request\x12\x10\n\x02ID\x18\x01 \x01(\x04\x42\x04\xc8\xde\x1f\x00\x12\x14\n\x06Method\x18\x02 \x01(\tB\x04\xc8\xde\x1f\x00\x12\x12\n\x04Path\x18\x03 \x01(\tB\x04\xc8\xde\x1f\x00\x12\x11\n\x03Val\x18\x04 \x01(\tB\x04\xc8\xde\x1f\x00\x12\x11\n\x03\x44ir\x18\x05 \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x17\n\tPrevValue\x18\x06 \x01(\tB\x04\xc8\xde\x1f\x00\x12\x17\n\tPrevIndex\x18\x07 \x01(\x04\x42\x04\xc8\xde\x1f\x00\x12\x17\n\tPrevExist\x18\x08 \x01(\x08\x42\x04\xc8\xde\x1f\x01\x12\x18\n\nExpiration\x18\t \x01(\x03\x42\x04\xc8\xde\x1f\x00\x12\x12\n\x04Wait\x18\n \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x13\n\x05Since\x18\x0b \x01(\x04\x42\x04\xc8\xde\x1f\x00\x12\x17\n\tRecursive\x18\x0c \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x14\n\x06Sorted\x18\r \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x14\n\x06Quorum\x18\x0e \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x12\n\x04Time\x18\x0f \x01(\x03\x42\x04\xc8\xde\x1f\x00\x12\x14\n\x06Stream\x18\x10 \x01(\x08\x42\x04\xc8\xde\x1f\x00\x12\x15\n\x07Refresh\x18\x11 \x01(\x08\x42\x04\xc8\xde\x1f\x01\"9\n\x08Metadata\x12\x14\n\x06NodeID\x18\x01 \x01(\x04\x42\x04\xc8\xde\x1f\x00\x12\x17\n\tClusterID\x18\x02 \x01(\x04\x42\x04\xc8\xde\x1f\x00\x42\x10\xc8\xe2\x1e\x01\xe0\xe2\x1e\x01\xd0\xe2\x1e\x01\xc8\xe1\x1e\x00')



_REQUEST = DESCRIPTOR.message_types_by_name['Request']
_METADATA = DESCRIPTOR.message_types_by_name['Metadata']
Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'etcdserver_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.Request)
  })
_sym_db.RegisterMessage(Request)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'etcdserver_pb2'
  # @@protoc_insertion_point(class_scope:etcdserverpb.Metadata)
  })
_sym_db.RegisterMessage(Metadata)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\310\342\036\001\340\342\036\001\320\342\036\001\310\341\036\000'
  _REQUEST.fields_by_name['ID']._options = None
  _REQUEST.fields_by_name['ID']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Method']._options = None
  _REQUEST.fields_by_name['Method']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Path']._options = None
  _REQUEST.fields_by_name['Path']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Val']._options = None
  _REQUEST.fields_by_name['Val']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Dir']._options = None
  _REQUEST.fields_by_name['Dir']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['PrevValue']._options = None
  _REQUEST.fields_by_name['PrevValue']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['PrevIndex']._options = None
  _REQUEST.fields_by_name['PrevIndex']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['PrevExist']._options = None
  _REQUEST.fields_by_name['PrevExist']._serialized_options = b'\310\336\037\001'
  _REQUEST.fields_by_name['Expiration']._options = None
  _REQUEST.fields_by_name['Expiration']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Wait']._options = None
  _REQUEST.fields_by_name['Wait']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Since']._options = None
  _REQUEST.fields_by_name['Since']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Recursive']._options = None
  _REQUEST.fields_by_name['Recursive']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Sorted']._options = None
  _REQUEST.fields_by_name['Sorted']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Quorum']._options = None
  _REQUEST.fields_by_name['Quorum']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Time']._options = None
  _REQUEST.fields_by_name['Time']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Stream']._options = None
  _REQUEST.fields_by_name['Stream']._serialized_options = b'\310\336\037\000'
  _REQUEST.fields_by_name['Refresh']._options = None
  _REQUEST.fields_by_name['Refresh']._serialized_options = b'\310\336\037\001'
  _METADATA.fields_by_name['NodeID']._options = None
  _METADATA.fields_by_name['NodeID']._serialized_options = b'\310\336\037\000'
  _METADATA.fields_by_name['ClusterID']._options = None
  _METADATA.fields_by_name['ClusterID']._serialized_options = b'\310\336\037\000'
  _REQUEST._serialized_start=47
  _REQUEST._serialized_end=430
  _METADATA._serialized_start=432
  _METADATA._serialized_end=489
# @@protoc_insertion_point(module_scope)
